# -*- coding: utf-8 -*-
# This file is part of pygal
#
# A python svg graph plotting library
# Copyright © 2012-2025 Kozea
#
# This library is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This library is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with pygal. If not, see <http://www.gnu.org/licenses/>.
"""Class holding state during render"""

from pygal.util import merge


class State(object):
    """
    Class containing config values
    overriden by chart values
    overriden by keyword args
    """

    def __init__(self, graph, **kwargs):
        """Create the transient state"""
        merge(self.__dict__, graph.config.__class__.__dict__)
        merge(self.__dict__, graph.config.__dict__)
        merge(self.__dict__, graph.__dict__)
        merge(self.__dict__, kwargs)



from pygal import Gauge


def test_gauge_reverse_direction():
    """Test that reverse_direction config is respected"""
    gauge = Gauge(reverse_direction=True)
    assert gauge.config.reverse_direction is True

    gauge.add('A', 10)
    gauge.range = (0, 10)
    gauge.setup()

    # When reversed, the polar box should be (0, 1, max, min)
    # min=0, max=10
    # reversed: (0, 1, 10, 0)
    assert gauge._box._tmin == 10
    assert gauge._box._tmax == 0
    assert gauge._box._rmin == 0
    assert gauge._box._rmax == 1

def test_gauge_normal_direction():
    """Test that normal direction works as expected"""
    gauge = Gauge()
    assert gauge.config.reverse_direction is False

    gauge.add('A', 10)
    gauge.range = (0, 10)
    gauge.setup()

    # min=0, max=10
    # normal: (0, 1, 0, 10)
    assert gauge._box._tmin == 0
    assert gauge._box._tmax == 10
    assert gauge._box._rmin == 0
    assert gauge._box._rmax == 1
